@@ -68,60 +68,6 @@ def get_dirs(
     return ret
 
 
-def change_extension(files: List[str], old: str, new: str) -> List[str]:
-    """
-    Change suffix of a list of file names
-
-    If a file does not have the specified old suffix, then it is not included
-    in the returned list
-
-    Args
-        files:
-            Paths of files
-
-        old:
-            The old suffix
-
-        new:
-            The new suffix
-
-    Returns:
-        A list of file names with new suffices
-    """
-    ret = []
-    for f in files:
-        if f.endswith(old):
-            ret.append(f[:-len(old)] + new)
-    return ret
-
-
-def change_prefix(files: List[str], old: str, new: str) -> List[str]:
-    """
-    Change prefix of a list of file names
-
-    If a file does not have the specified old suffix, then it is not included
-    in the returned list
-
-    Args
-        files:
-            Paths of files
-
-        old:
-            The old prefix
-
-        new:
-            The new prefix
-
-    Returns:
-        A list of file names with new suffices
-    """
-    ret = []
-    for f in files:
-        if f.startswith(old):
-            ret.append(new + f[len(old):])
-    return ret
-
-
 def concat(files: List[str], output: str):
     """
     Args:
@@ -133,7 +79,7 @@ def concat(files: List[str], output: str):
     call(f"cat {' '.join(files)} > {output}")
 
 
-def zip_broadcast(*lists):
+def zip_broadcast(*lists) -> List[tuple]:
     """
     This is a broadcasting version of the built-in zip() function
     """
@@ -255,3 +201,61 @@ def tar_list(file: str) -> List[str]:
     """
     stdout = check_output(f'tar -tf "{file}"')
     return stdout.strip().split('\n')
+
+
+def get_temp_path(
+        prefix: str = 'temp',
+        suffix: str = '') -> str:
+    """
+    Returns a temp file name that does not exist, i.e. temp000.txt
+
+    Args:
+        prefix:
+            Can include the path
+
+        suffix:
+            Usually the file extension
+    """
+    i = 1
+    while True:
+        fpath = f'{prefix}{i:03}{suffix}'
+        if not os.path.exists(fpath):
+            return fpath
+        i += 1
+
+
+def gzip(
+        file: str,
+        keep: bool = True,
+        output: Optional[str] = None) -> str:
+    """
+    gzip or gunzip files
+
+    Args:
+        file: path-like
+
+        keep:
+            Keep the input file or not
+
+        output: path-like
+    """
+    is_gz = file.endswith('.gz')
+    decompress = '--decompress' if is_gz else ''
+
+    if output is None:
+        if is_gz:
+            output = f'{file[:-3]}'
+        else:
+            output = f'{file}.gz'
+
+    args = [
+        'gzip', decompress, '--stdout', f'"{file}"', ">", f'"{output}"'
+    ]
+
+    cmd = ' '.join(args)
+    call(cmd=cmd)
+
+    if not keep:
+        os.remove(file)
+
+    return output
\ No newline at end of file
